"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputsource import InputSource, InputSourceTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class BeginDeliveryNoteFieldExtractionRequestBodyTypedDict(TypedDict):
    r"""Request to process a document using the delivery-note model"""

    input_source: InputSourceTypedDict
    r"""The source of the document(s) to be processed"""


class BeginDeliveryNoteFieldExtractionRequestBody(BaseModel):
    r"""Request to process a document using the delivery-note model"""

    input_source: Annotated[InputSource, pydantic.Field(alias="inputSource")]
    r"""The source of the document(s) to be processed"""
