"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from typing_extensions import TypedDict


class URLInputSourceTypedDict(TypedDict):
    r"""Input the URL of a remote file."""

    url: str
    r"""The URL of the remote file"""


class URLInputSource(BaseModel):
    r"""Input the URL of a remote file."""

    url: str
    r"""The URL of the remote file"""
