"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from abbyy_document_ai.types import BaseModel
from typing_extensions import TypedDict


class ConversionResultsTypedDict(TypedDict):
    r"""The response from the `getConversionResults` endpoint."""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""


class ConversionResults(BaseModel):
    r"""The response from the `getConversionResults` endpoint."""

    meta: Document
    r"""Represents a document that has been submitted for processing."""
