"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class URLListInputSourceTypedDict(TypedDict):
    r"""Input the URLs of multiple remote files."""

    urls: List[str]


class URLListInputSource(BaseModel):
    r"""Input the URLs of multiple remote files."""

    urls: List[str]
