"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hotelinvoice import HotelInvoice, HotelInvoiceTypedDict
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from abbyy_document_ai.types import BaseModel
from abbyy_document_ai.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetExtractedHotelInvoiceFieldsRequestTypedDict(TypedDict):
    document_id: str
    r"""The id of the document"""


class GetExtractedHotelInvoiceFieldsRequest(BaseModel):
    document_id: Annotated[
        str,
        pydantic.Field(alias="documentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The id of the document"""


class GetExtractedHotelInvoiceFieldsResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    hotel_invoice: NotRequired[HotelInvoiceTypedDict]
    r"""Extracted Hotel Invoice Data Response"""


class GetExtractedHotelInvoiceFieldsResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    hotel_invoice: Optional[HotelInvoice] = None
    r"""Extracted Hotel Invoice Data Response"""
