"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class RawInputSourceTypedDict(TypedDict):
    r"""Input a document as a base64 encoded string."""

    base64_encoded_content: str
    r"""The base64 encoded content of the file"""
    name: str
    r"""The name of the file"""


class RawInputSource(BaseModel):
    r"""Input a document as a base64 encoded string."""

    base64_encoded_content: Annotated[str, pydantic.Field(alias="base64EncodedContent")]
    r"""The base64 encoded content of the file"""

    name: str
    r"""The name of the file"""
