"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rawinputsource import RawInputSource, RawInputSourceTypedDict
from .urlinputsource import URLInputSource, URLInputSourceTypedDict
from .urllistinputsource import URLListInputSource, URLListInputSourceTypedDict
from typing import Union
from typing_extensions import TypeAliasType


InputSourceTypedDict = TypeAliasType(
    "InputSourceTypedDict",
    Union[
        URLInputSourceTypedDict, URLListInputSourceTypedDict, RawInputSourceTypedDict
    ],
)
r"""The source of the document(s) to be processed"""


InputSource = TypeAliasType(
    "InputSource", Union[URLInputSource, URLListInputSource, RawInputSource]
)
r"""The source of the document(s) to be processed"""
